/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 12, 2002, 9:41 PM
 *
 * 2004-01-16 v.0.5.3 Updated to be Serializable
 * 2004-04-26 v.0.5.4 isSameMeasurementType
 */

package org.xspace.mx.physics;

import org.xspace.mx.Unit;
import org.xspace.mx.UnitType;
import org.xspace.mx.SystemOfUnits;

/**
 * The <a href="http://physics.nist.gov/cuu/Units">Systeme International (SI)</a>
 * {@link org.xspace.mx.SystemOfUnits} represents a standard set of physical units
 * against which other measurments can be compared.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class SI implements SystemOfUnits {  
// public class SI implements SystemOfUnits, java.io.Serializable {  // Serializable of SI does not appear to be needed so far  
  static final long serialVersionUID = -6725266115456836608L;
  private static final int SERIALIZATION_VERSION = 1;
  
  private static SystemOfUnits standard = new SI();
  public static SystemOfUnits getSystem() {return standard;}
  
  /** Creates a new instance of SI */
  private SI() {
  }

  /**
   * An instance of {@link org.xspace.mx.Unit} that represents a length within the SI.
   */
  public static class Length implements Unit, java.io.Serializable {
    static final long serialVersionUID = 4756211714542356383L;
    
    private static final UnitType type = new LengthType();
    
    private transient double power = 0;
    public double getPower() {return power;}    
    public void setPower(double power) {this.power = power;}    

    public org.xspace.mx.UnitType getType() {return type;}
    
    public Length() {}
    public Length(double power) {
      this.power = power;
    }
    
    
    /**
     * Serialization writeObject
     */   
    private void writeObject(java.io.ObjectOutputStream oos) throws java.io.IOException {
      oos.defaultWriteObject();

      oos.writeInt(SERIALIZATION_VERSION); // Version Number
      oos.writeDouble(power); // System Value
    }    
    /**
     * Serialization readObject
     */   
    private void readObject(java.io.ObjectInputStream ois) throws java.io.IOException, ClassNotFoundException {    
      ois.defaultReadObject();

      int iVersion = ois.readInt();
      switch (iVersion) {
        case 1:
          power = ois.readDouble(); // Power
          break;
        default:
          // Unexpected
          break;
      }
    }
  }  
  private static class LengthType implements UnitType {
    public LengthType() {}
    public String toString() {return "Length";}
  }

  
  /**
   * An instance of {@link org.xspace.mx.Unit} that represents a time within the SI.
   */
  public static class Time implements Unit, java.io.Serializable {
    static final long serialVersionUID = 3903510510945583792L;
    
    private static final UnitType type = new TimeType();
    
    private transient double power = 0;
    public double getPower() {return power;}    
    public void setPower(double power) {this.power = power;}    
    
    public org.xspace.mx.UnitType getType() {return type;}
    
    public Time() {}
    public Time(double power) {
      this.power = power;
    }

    
    /**
     * Serialization writeObject
     */   
    private void writeObject(java.io.ObjectOutputStream oos) throws java.io.IOException {
      oos.defaultWriteObject();
      
      oos.writeInt(SERIALIZATION_VERSION); // Version Number
      oos.writeDouble(power); // System Value
    }    
    /**
     * Serialization readObject
     */   
    private void readObject(java.io.ObjectInputStream ois) throws java.io.IOException, ClassNotFoundException {    
      ois.defaultReadObject();

      int iVersion = ois.readInt();
      switch (iVersion) {
        case 1:
          power = ois.readDouble(); // Power
          break;
        default:
          // Unexpected
          break;
      }
    }
    
  }  
  private static class TimeType implements UnitType {
    public TimeType() {}
    public String toString() {return "Time";}
  }

  
  /**
   * An instance of {@link org.xspace.mx.Unit} that represents a mass within the SI.
   */
  public static class Mass implements Unit, java.io.Serializable {
    static final long serialVersionUID = -8408446358102867896L;
    
    private static final UnitType type = new MassType();
    
    private transient double power = 0;
    public double getPower() {return power;}    
    public void setPower(double power) {this.power = power;}    
    
    public UnitType getType() {return type;}
    
    public Mass() {}
    public Mass(double power) {
      this.power = power;
    }
    
    /**
     * Serialization writeObject
     */   
    private void writeObject(java.io.ObjectOutputStream oos) throws java.io.IOException {
      oos.defaultWriteObject();

      oos.writeInt(SERIALIZATION_VERSION); // Version Number
      oos.writeDouble(power); // System Value
    }    
    /**
     * Serialization readObject
     */   
    private void readObject(java.io.ObjectInputStream ois) throws java.io.IOException, ClassNotFoundException {    
      ois.defaultReadObject();

      int iVersion = ois.readInt();
      switch (iVersion) {
        case 1:
          power = ois.readDouble(); // Power
          break;
        default:
          // Unexpected
          break;
      }
    }
    
  }
  private static class MassType implements UnitType {
    public MassType() {}
    public String toString() {return "Mass";}
  }  


  /**
   * An instance of {@link org.xspace.mx.Unit} that represents an angle within the SI.
   */
  public static class Angle implements Unit, java.io.Serializable {
    static final long serialVersionUID = -5252013663334140351L;
    
    private static final UnitType type = new AngleType();
    
    private transient double power = 0;
    public double getPower() {return power;}
    public void setPower(double power) {this.power = power;}
    
    public UnitType getType() {return type;}
    
    public Angle() {}
    public Angle(double power) {
      this.power = power;
    }
    
    /**
     * Serialization writeObject
     */   
    private void writeObject(java.io.ObjectOutputStream oos) throws java.io.IOException {
      oos.defaultWriteObject();

      oos.writeInt(SERIALIZATION_VERSION); // Version Number
      oos.writeDouble(power); // System Value
    }    
    /**
     * Serialization readObject
     */   
    private void readObject(java.io.ObjectInputStream ois) throws java.io.IOException, ClassNotFoundException {    
      ois.defaultReadObject();

      int iVersion = ois.readInt();
      switch (iVersion) {
        case 1:
          power = ois.readDouble(); // Power
          break;
        default:
          // Unexpected
          break;
      }
    }    
  }
  private static class AngleType implements UnitType {
    public AngleType() {}
    public String toString() {return "Angle";}
  }  

  
  
  /**
   * <p>Determine whether this measurement and the other measurement are comparable.</p>
   *
   * <p>Both measurements may have different numbers of dimensions.  All dimensions
   * of both measurements will be checked.</p>
   */
  public static boolean isSameMeasurementType(org.xspace.mx.Measurement first, org.xspace.mx.Measurement second) {
    if (first == null || second == null) {
      return false;      
    }
    
    // Check the System being used
    if (first.getSystem() != second.getSystem()) {
      return false;
    }
    
    // Check the number of dimensions
    Unit[] firstDims = first.getSystemDimensions();
    Unit[] secondDims = second.getSystemDimensions();
    
    
    // Check powers of each dimension within the first Measurement
    boolean[] bSecondUnitTypeAlreadyChecked = new boolean[secondDims.length]; // Default to false
    for (int i = 0; i < firstDims.length; i++) {
      Unit firstUnit = firstDims[i];
      
      double firstPower = firstUnit.getPower();
      if (Math.abs(firstPower) > TOL) {
        // Skip this dimension; insignificant
        continue;
      }      
      UnitType firstType = firstUnit.getType();
      
      
      // Loop through the second's dimensions
      boolean bUnitFoundAndChecked = false;
      for (int j = 0; j < secondDims.length; j++) {
        Unit secondUnit = secondDims[i];
        
        UnitType secondType = secondUnit.getType();
        
        if (firstType == secondType) {
          if (Math.abs(firstPower - secondUnit.getPower()) > TOL) {
            return false;
          } else {
            bUnitFoundAndChecked = true;
          }
          
          bSecondUnitTypeAlreadyChecked[j] = true;
        }
      } // end of inner loop
      
      if (!bUnitFoundAndChecked) {
        return false;
      }
    } // end of checking powers of each dimension within the first Measurement
    
    

    // Check powers of each dimension within the second Measurement
    // For efficiency, skip those dimensions which have already been checked
    for (int i = 0; i < secondDims.length; i++) {
      if (bSecondUnitTypeAlreadyChecked[i]) {
        // For efficiency, move on to next unit type
        continue;
      }
      
      Unit secondUnit = secondDims[i];
      
      double secondPower = secondUnit.getPower();
      // BUG if (Math.abs(secondPower) > TOL) {
      if (Math.abs(secondPower) < TOL) {
        // Skip this dimension; insignificant
        continue;
      } else {
        // Something significant which was not found in the first measurment's dimensions
        // Therefore, the two measurements are different!
        return false;
      }
    } // end of checking powers of each dimension within the second Measurement    
    
    return true;
  }
  
  private static final double TOL = 1e-20;  
}
