/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a centimeter.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Centimeter extends Length {
  
  /**
   * Creates a Measurement equal to one Centimeter
   */
  public Centimeter() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Centimeters
   *
   * @param value The number of Centimeters
   */
  public Centimeter(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 0.01;
    this.systemValue = scaling * value;
  }

  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Centimeter(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.cm));
  }  
  
  /**
   * An abbreviated description of the units of a Centimeter
   *
   * @return The string "cm"
   */
  public String getAbbr() {return "cm";}

  /**
   * A description of the units of a Centimeter
   *
   * @return The string "centimeters"
   */
  public String getDescription() {return "centimeters";}  
}
