/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 *
 * Updated April 23, 2004
 * - Extends Force class
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a Newton.
 *
 * @author Michel Santos
 * @since 0.5
 */
// public class Newton extends BaseUnit {
public class Newton extends Force {
  
  /**
   * Creates a Measurement equal to one Newton
   */
  public Newton() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Newtons
   *
   * @param value The number of Newtons
   */
  public Newton(double value) {
    dims[DIM_LENGTH].setPower(1);
    dims[DIM_TIME].setPower(-2);
    dims[DIM_MASS].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }

  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Newton(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.N));
  }  
  
  /**
   * An abbreviated description of the units of a Newton
   *
   * @return The string "N"
   */
  public String getAbbr() {return "N";}
  
  /**
   * A description of the units of a Newton
   *
   * @return The string "Newtons"
   */  
  public String getDescription() {return "Newtons";}  
}
