/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on April 2003
 */

package org.xspace.mx.physics.immutable;

/**
 * A Measurement representing a second.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class Second extends Time {
  
  /**
   * Creates a Measurement equal to one Second
   */
  public Second() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Seconds
   *
   * @param value The number of Seconds
   */
  public Second(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }
  
  /**
   * Creates a Measurement that is equivalent to the input
   */
  public Second(org.xspace.mx.Measurement mx) {
    this(mx.getValue(Units.s));
  }  

  /**
   * An abbreviated description of the units of a Second
   *
   * @return The string "s"
   */
  public String getAbbr() {return "s";}
  
  /**
   * A description of the units of a Second
   *
   * @return The string "seconds"
   */  
  public String getDescription() {return "seconds";}

}
