/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on March 30, 2003, 3:51 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a centimeter.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Centimeter extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Centimeter
   */
  public Centimeter() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Centimeters
   *
   * @param value The number of Centimeters
   */
  public Centimeter(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 0.01;
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of a Centimeter
   *
   * @return The string "cm"
   */
  public String getAbbr() {return "cm";}  

  /**
   * A description of the units of a Centimeter
   *
   * @return The string "centimeters"
   */
  public String getDescription() {return "centimeters";}  
}
