/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 7:29 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a day.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Day extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Day
   */
  public Day() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Days
   *
   * @param value The number of Days
   */
  public Day(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 60 * 60  * 24;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Day
   *
   * @return The string "day"
   */
  public String getAbbr() {return "day";}

  /**
   * A description of the units of a Day
   *
   * @return The string "days"
   */
  public String getDescription() {return "days";}    
}
