/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 2:49 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a foot.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Foot extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Foot
   */
  public Foot() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Feet
   *
   * @param value The number of Feet
   */
  public Foot(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 0.3048;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Foot
   *
   * @return The string "ft"
   */
  public String getAbbr() {return "ft";}

  /**
   * A description of the units of a Foot
   *
   * @return The string "feet"
   */
  public String getDescription() {return "feet";}
}
