/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:17 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing an hour.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Hour extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Hour
   */
  public Hour() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Hours
   *
   * @param value The number of Hours
   */
  public Hour(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 3600;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of an Hour
   *
   * @return The string "hr"
   */
  public String getAbbr() {return "hr";}

  /**
   * A description of the units of an Hour
   *
   * @return The string "hours"
   */  
  public String getDescription() {return "hours";}
}
