/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on March 30, 2003, 5:45 PM
 */

package org.xspace.mx.physics.mutable;


/**
 * An immutable wrapper for other angular units.  
 * 
 * @author Michel Santos
 * @since 0.5
 */
public class ImmutableAngle extends Immutable implements org.xspace.mx.physics.Angle {
  
  /**
   * Creates a new instance of ImmutableAngle.
   * <br>
   * <b>The dimensions of the input measurement will be checked to assure that it is an angle.</b>
   *   
   * @param protectThis The other Measurement that will be protected.
   */
  public ImmutableAngle(org.xspace.mx.Measurement protectThis) {
    super(protectThis);
    
    // Safety-check
    /**
     * Confirm that the base unit is in fact an angle unit
     * One way to check this is to get its value in terms of radians
     * If this should fail, then an exception will be thrown
     */    
    protectThis.getValue(org.xspace.mx.physics.mutable.Units.rad);
  }
  
}