/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on March 30, 2003, 5:37 PM
 */

package org.xspace.mx.physics.mutable;


/**
 * An immutable wrapper for other mass units.
 *
 * @author Michel Santos
 * @since 0.5
 */
public class ImmutableMass extends Immutable implements org.xspace.mx.physics.Mass {
  
  /**
   * Creates a new instance of ImmutableMass.
   * <br>
   * <b>The dimensions of the input measurement will be checked to assure that it is a mass.</b>
   *   
   * @param protectThis The other Measurement that will be protected.
   */
  public ImmutableMass(org.xspace.mx.Measurement protectThis) {
    super(protectThis);
    
    // Safety-check
    /**
     * Confirm that the base unit is in fact a mass unit
     * One way to check this is to get its value in terms of kilograms
     * If this should fail, then an exception will be thrown
     */    
    protectThis.getValue(org.xspace.mx.physics.mutable.Units.kg);
  }
  
}
