/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 2002
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a meter.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Meter extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Meter
   */
  public Meter() {
    this(1);
  }

  /**
   * Creates a Measurement as a multiple of Meters
   *
   * @param value The number of Meters
   */  
  public Meter(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of a Meter
   *
   * @return The string "m"
   */
  public String getAbbr() {return "m";}  

  
  /**
   * A description of the units of a Meter
   *
   * @return The string "meters"
   */
  public String getDescription() {return "meters";}

}
