/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:33 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a mile.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Mile extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Mile
   */
  public Mile() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Miles
   *
   * @param value The number of Miles
   */
  public Mile(double value) {
    dims[DIM_LENGTH].setPower(1);
    
    double scaling = 1609.344;
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of a Mile
   *
   * @return The string "mi"
   */
  public String getAbbr() {return "mi";}  
  

  /**
   * A description of the units of a Mile
   *
   * @return The string "miles"
   */
  public String getDescription() {return "miles";}
  
}
