/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 7:10 PM
 *
 * Updated April 23, 2004
 * - Extends Force class
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a pound of force.  
 * This is equivalent to the <i>weight</i> of a pound of mass under the influence
 * of Earth's gravity at mean sea level.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class PoundForce extends Force {
  
  /**
   * Creates a Measurement equal to one Pound Force
   */
  public PoundForce() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Pound Forces
   *
   * @param value The number of Pound Forces
   */
  public PoundForce(double value) {
    dims[DIM_LENGTH].setPower(1);
    dims[DIM_TIME].setPower(-2);
    dims[DIM_MASS].setPower(1);
    
    double scaling = 4.44822161526;
    this.systemValue = scaling * value;
  }
  
  /**
   * An abbreviated description of the units of a Pound Force
   *
   * @return The string "lbf"
   */
  public String getAbbr() {return "lbf";}
  
  
  /**
   * A description of the units of a Pound Force
   *
   * @return The string "pounds force"
   */
  public String getDescription() {return "pounds force";}    
}
