/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created on October 13, 2002, 5:15 PM
 */

package org.xspace.mx.physics.mutable;

/**
 * A Measurement representing a second.
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Second extends BaseUnit {
  
  /**
   * Creates a Measurement equal to one Second
   */
  public Second() {
    this(1);
  }
  
  /**
   * Creates a Measurement as a multiple of Seconds
   *
   * @param value The number of Seconds
   */
  public Second(double value) {
    dims[DIM_TIME].setPower(1);
    
    double scaling = 1.0;
    this.systemValue = scaling * value;
  }

  /**
   * An abbreviated description of the units of a Second
   *
   * @return The string "s"
   */
  public String getAbbr() {return "s";}
  
  /**
   * A description of the units of a Second
   *
   * @return The string "seconds"
   */  
  public String getDescription() {return "seconds";}
}
