/*
 * Copyright (C) 2002-2006 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE.txt for more information.
 *
 * Created October 2002
 *
 * Updated April 23, 2004
 * - Added utility functions to check for compatible units
 */

package org.xspace.mx.physics.mutable;

import org.xspace.mx.Measurement;


/**
 * Helpler class to provide easy access to <i>standard</i> measurements.
 * <i>These measurements are immutable.</i>
 *
 * @author Michel Santos
 * @since 0.1
 */
public class Units {
  
  /** Creates a new instance of Units */
  private Units() {
  }

  // Angular constants
  public static final Measurement rad = new Immutable(new Radian());
  public static final Measurement deg = new Immutable(new Degree());
  public static final Measurement rev = new Immutable(new Revolution());
  
  
  // Length constants
  public static final Measurement m = new Immutable(new Meter());
  public static final Measurement cm = new Immutable(new Centimeter());
  public static final Measurement km = new Immutable(new Kilometer());
  public static final Measurement AU = new Immutable(new AstronomicalUnit());
  public static final Measurement ft = new Immutable(new Foot());
  public static final Measurement in = new Immutable(new Inch());
  public static final Measurement mi = new Immutable(new Mile());
  
  // Time constants
  public static final Measurement s = new Immutable(new Second());
  public static final Measurement min = new Immutable(new Minute());  
  public static final Measurement hr = new Immutable(new Hour());
  public static final Measurement day = new Immutable(new Day());
  
  // Mass constants
  public static final Measurement kg = new Immutable(new Kilogram());
  
  // Force constants
  public static final Measurement N = new Immutable(new Newton());
  public static final Measurement lbf = new Immutable(new PoundForce());  

  
  public static boolean isLengthUnit(org.xspace.mx.physics.mutable.BaseUnit mx) {
    return mx.isSameMeasurementType(Units.m);
  }
  
  public static boolean isTimeUnit(org.xspace.mx.physics.mutable.BaseUnit mx) {
    return mx.isSameMeasurementType(Units.s);
  }

  public static boolean isForceUnit(org.xspace.mx.physics.mutable.BaseUnit mx) {
    return mx.isSameMeasurementType(Units.N);
  }
  
  private static Measurement MX_METERS_PER_SECOND = Units.m.div(Units.s);
  public static boolean isSpeedUnit(org.xspace.mx.physics.mutable.BaseUnit mx) {
    return mx.isSameMeasurementType(MX_METERS_PER_SECOND);
  }


  
  public static boolean isLengthUnit(org.xspace.mx.Measurement mx) {
    return org.xspace.mx.physics.SI.isSameMeasurementType(mx, Units.m);
  }
  public static boolean isForceUnit(org.xspace.mx.Measurement mx) {
    return org.xspace.mx.physics.SI.isSameMeasurementType(mx, Units.N);
  }
  public static boolean isSpeedUnit(org.xspace.mx.Measurement mx) {
    return org.xspace.mx.physics.SI.isSameMeasurementType(mx, MX_METERS_PER_SECOND);
  }
  
  
}
