/*
 * Copyright (C) 2002-2004 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE for more information.
 *
 * Created on April 7, 2003, 3:47 PM
 */

package org.xspace.mx;


import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;
import org.xspace.mx.physics.immutable.Centimeter;
import org.xspace.mx.physics.immutable.Day;
import org.xspace.mx.physics.immutable.Foot;
import org.xspace.mx.physics.immutable.Hour;
import org.xspace.mx.physics.immutable.Kilogram;
import org.xspace.mx.physics.immutable.Kilometer;
import org.xspace.mx.physics.immutable.Meter;
import org.xspace.mx.physics.immutable.Minute;
import org.xspace.mx.physics.immutable.Second;
import org.xspace.mx.physics.immutable.Units;

/**
 *
 * @author Michel Santos
 */
public class ImmutableTester extends TestCase {
  
  public ImmutableTester(java.lang.String testName) {
    super(testName);
  }
  
  public static void main(java.lang.String[] args) {
    TestRunner.run(suite());
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(ImmutableTester.class);
    return suite;
  }
  
  public void testTimes1() {
    Measurement minute = new Minute();
    System.out.println("1 Minute = " + minute);
    System.out.println("1 Minute as a multiple of seconds: " + minute.getValue(new Second()));
    System.out.println("1 Minute as a multiple of seconds: " + minute.getValue(Units.s));
    assertEquals(60, minute.getValue(new Second()), 0);
    assertEquals(60, minute.getValue(Units.s), 0);  // Alternative check using "standard" units
    assertEquals(1.0/60, minute.getValue(Units.hr), 0);  // Check as a multiple of one hour
    
    Measurement threeMinutes = new Minute(3);
    System.out.println("3 Minutes = " + threeMinutes);
    System.out.println("3 Minute as a multiple of seconds: " + threeMinutes.getValue(Units.s));
    assertEquals(180, threeMinutes.getValue(new Second()), 0);
    assertEquals(180, threeMinutes.getValue(Units.s), 0); // Alternative check using "standard" units
    

    Measurement day = new Day();
    System.out.println("One Day = " + day);
    System.out.println("One Day as a multiple of hours: " + day.getValue(Units.hr));
    System.out.println("One Day as a multiple of minutes: " + day.getValue(Units.min));
    assertEquals(1, day.getValue(Units.day), 0);
    assertEquals(24, day.getValue(Units.hr), 0);
    assertEquals(24 * 60, day.getValue(Units.min), 0);
    assertEquals(24 * 60 * 60, day.getValue(Units.s), 0);
  }

  public void testTimeArithmetic() {
    Measurement mxA = new Kilogram(5);
    System.out.println();
    System.out.println("mxA: " + mxA);
    
    Measurement mxB = mxA.mult(3);
    System.out.println();
    System.out.println("mxA: " + mxA);
    System.out.println("mxB: " + mxB);
    
    Measurement mxC = mxB.div(2);
    System.out.println();
    System.out.println("mxA: " + mxA);
    System.out.println("mxB: " + mxB);
    System.out.println("mxC: " + mxC);
    
    Measurement mxD = new Kilogram(100); // 100 kg
    Measurement mxAddition = mxA.plus(mxD);
    System.out.println();
    System.out.println("mxA: " + mxA);
    System.out.println("mxD: " + mxD);
    System.out.println("mxAddition: " + mxAddition);
    
    assertEquals(5, mxA.getValue(Units.kg), 0);
    assertEquals(15, mxB.getValue(Units.kg), 0);
    assertEquals(7.5, mxC.getValue(Units.kg), 0);
    assertEquals(100, mxD.getValue(Units.kg), 0);
    assertEquals(105, mxAddition.getValue(Units.kg), 0);
  }

  public void testSpeeds() {
    double dTOL = 1e-6;
    
    // 65 kph
    Measurement speed = new Kilometer(65).div(new Hour());
    System.out.println("Speed: " + speed);
    assertEquals(speed.getSystemValue(), 18.05555556, dTOL);
    
    // Measure the speed in terms of 5 cm/s
    Measurement specialSpeed = new Centimeter(5).div(new Second());
    System.out.println("5 cm/s: " + specialSpeed);
    double value = speed.getValue(specialSpeed);
    System.out.println("Speed as multiple of 5 cm/s: " + value);
    assertEquals(value, 361.111112, dTOL);
  }  
}
