/*
 * Copyright (C) 2002-2004 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE for more information.
 *
 * Created on October 2, 2002, 6:56 PM
 */

package org.xspace.mx;


import org.xspace.mx.physics.Length;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;
import org.xspace.mx.physics.mutable.BaseUnit;
import org.xspace.mx.physics.mutable.Day;
import org.xspace.mx.physics.mutable.Degree;
import org.xspace.mx.physics.mutable.Foot;
import org.xspace.mx.physics.mutable.Hour;
import org.xspace.mx.physics.mutable.Immutable;
import org.xspace.mx.physics.mutable.ImmutableLength;
import org.xspace.mx.physics.mutable.Inch;
import org.xspace.mx.physics.mutable.Meter;
import org.xspace.mx.physics.mutable.Mile;
import org.xspace.mx.physics.mutable.Minute;
import org.xspace.mx.physics.mutable.Newton;
import org.xspace.mx.physics.mutable.PoundForce;
import org.xspace.mx.physics.mutable.Radian;
import org.xspace.mx.physics.mutable.Second;
import org.xspace.mx.physics.mutable.Units;


/**
 *
 * @author Michel Santos
 */
public class MutableTester extends TestCase {
  
  public MutableTester(java.lang.String testName) {
    super(testName);
  }
  
  public static void main(java.lang.String[] args) {
    TestRunner.run(suite());
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(MutableTester.class);
    return suite;
  }
  
  public void testDimensionless() {
    Measurement x = new BaseUnit();
    java.lang.System.out.println(x);
  }
  
  private double TOL = 1e-9;
  public void testDimensionlessArithmetic() {
    double a = 3.5;
    Measurement x = new BaseUnit(a);
    
    double b = 2;
    Measurement y = new BaseUnit(b);
    Measurement z;
    
    z = x.copy();
    z.plus(y);
    assertEquals(z.getSystemValue(), a + b, TOL);
    
    z = x.copy();
    z.minus(y);
    assertEquals(z.getSystemValue(), a - b, TOL);
    
    z = x.copy();
    z.mult(b);
    assertEquals(z.getSystemValue(), a * b, TOL);
    
    z = x.copy();
    z.div(b);
    assertEquals(z.getSystemValue(), a / b, TOL);
    
    z = x.copy();
    z.pow(b);
    assertEquals(z.getSystemValue(), Math.pow(a, b), TOL);
    
    z = x.copy();
    z.root(b);
    assertEquals(z.getSystemValue(), Math.pow(a, 1.0/b), TOL);
  }
  
  public void testSystemArithmetic() {
    double a = 3.5;
    Measurement x = new Meter(a);
    System.out.println("X = " + x);
    
    double b = -1.5;
    Measurement y = new Meter(b);
    
    double c = 2;
    Measurement z;
    
    z = x.copy();
    z.plus(y);
    assertEquals(z.getSystemValue(), a + b, TOL);
    
    z = x.copy();
    z.minus(y);
    assertEquals(z.getSystemValue(), a - b, TOL);
    
    z = x.copy();
    z.mult(b);
    assertEquals(z.getSystemValue(), a * b, TOL);
    
    z = x.copy();
    z.div(b);
    assertEquals(z.getSystemValue(), a / b, TOL);
    
    z = x.copy();
    z.pow(b);
    assertEquals(z.getSystemValue(), Math.pow(a, b), TOL);
    
    z = x.copy();
    z.root(b);
    assertEquals(z.getSystemValue(), Math.pow(a, 1.0/b), TOL);
    
    
    z = x.copy();
    z.mult(y);
    assertEquals(z.getSystemValue(), a * b, TOL);
    Measurement mSquared = new Meter().mult(new Meter());
    assertEquals(z.getValue(mSquared), a * b, TOL);
    
    z = x.copy();
    z.div(y);
    assertEquals(z.getSystemValue(), a / b, TOL);
    assertEquals(z.getValue(new BaseUnit(1)), a / b, TOL);
  }
  
  public void testArithmetic() {
    double a = 3.5;
    Measurement x = new Meter(a);
    System.out.println("X = " + x);
    
    double b = -1.5;
    Measurement y = new Foot(b);
    
    Measurement z;
    
    z = x.copy();
    z.plus(y);
    assertEquals(z.getSystemValue(), 3.0428, TOL); // meters
    
    z = x.copy();
    z.minus(y);
    assertEquals(z.getSystemValue(), 3.95719999999999, TOL);
    
    z = x.copy();
    z.mult(y);
    assertEquals(z.getSystemValue(), a * .3048 * b, TOL);
    
    z = x.copy();
    z.div(y);
    assertEquals(z.getSystemValue(), a / (.3048 * b), TOL);
    
    z = x.copy();
    z.pow(b);
    assertEquals(z.getSystemValue(), Math.pow(a, b), TOL);
    
    z = x.copy();
    z.root(b);
    assertEquals(z.getSystemValue(), Math.pow(a, 1.0/b), TOL);
    
    
    z = x.copy();
    z.mult(y);
    Measurement inSquared = new Inch().mult(new Inch());
    assertEquals(z.getValue(inSquared), -2480.31496063, TOL);
    
    z = x.copy();
    z.div(y);
    assertEquals(z.getValue(new BaseUnit(1)), -7.65529308835, TOL);
  }
  
  public void testTimes() {    
    Measurement minute = new Minute();
    System.out.println("1 Minute = " + minute);    
    assertEquals(60, minute.getValue(new Second()), 0);
    assertEquals(60, minute.getValue(Units.s), 0);  // Alternative check using "standard" units
    assertEquals(1.0/60, minute.getValue(Units.hr), 0);  // Check as a multiple of one hour
    
    Measurement threeMinutes = new Minute(3);
    System.out.println("3 Minutes = " + threeMinutes);
    assertEquals(180, threeMinutes.getValue(new Second()), 0);
    assertEquals(180, threeMinutes.getValue(Units.s), 0); // Alternative check using "standard" units
    

    Measurement day = new Day();
    System.out.println("One Day = " + day);
    assertEquals(1, day.getValue(Units.day), 0);
    assertEquals(24, day.getValue(Units.hr), 0);
    assertEquals(24 * 60, day.getValue(Units.min), 0);
    assertEquals(24 * 60 * 60, day.getValue(Units.s), 0);
  }
  
  
  public void testSpeeds() {
    // 65 mph
    System.out.println("Hour: " + new Hour());
    Measurement speed = new Mile(65).div(new Hour());
    System.out.println("Speed: " + speed);
    assertEquals(speed.getSystemValue(), 29.0576, TOL);    
    
    // Measure the speed in terms of 5 in/s
    Measurement specialSpeed = new Inch(5).div(new Second());
    System.out.println("specialSpeed: " + specialSpeed);
    double value = speed.getValue(specialSpeed);
    assertEquals(value, 228.8, TOL);
  }
  
  public void testMasses() {
    Measurement N = new Newton();
    for (int i = 0; i < 1000; i++) {
      Measurement weight = new PoundForce(100);
      assertEquals(weight.getValue(N), 444.822161526, TOL);
    }
  }
  
  public void testImmutability() {
    Measurement g = new Immutable(Units.m.mult(9.8).div(Units.s.pow(2)));
    Measurement force = g.mult(Units.kg.mult(88.45));
    
    double mag = force.getSystemValue();
    assertEquals(867.4032, mag, 1);
    
    assertEquals(Units.lbf.mult(195).getValue(Units.lbf), force.getValue(Units.lbf), 2e-1);
    
    assertEquals(9.8, g.getValue(Units.m.div(Units.s.pow(2))), 1e-6);
    assertEquals(9.8, g.getSystemValue(),  1e-6);
  }
  
  public void testAngles() {
    Measurement DEG = new Degree();
    
    Measurement result = new Degree(90).plus(new Radian(Math.PI));
    double mag = result.getValue(DEG);
    assertEquals(270, mag, 1e-12);
    
    result = new Degree(-90).plus(new Radian(Math.PI));
    mag = result.getValue(DEG);
    assertEquals(90, mag, 1e-12);
    
    result = new Degree(-90).plus(new Radian(-Math.PI));
    mag = result.getValue(DEG);
    assertEquals(-270, mag, 1e-12);
    
    result = new Degree(-90).mult(4);
    mag = result.getValue(DEG);
    assertEquals(-360, mag, 1e-12);    
  }
  
  public void testMutability() {
    Measurement a = new Meter(5);
    System.out.println("a: " + a);
    
    Measurement b = new Immutable(a);
    System.out.println("b (before): " + b);
    
    Measurement c = b.mult(3);
    System.out.println("b (after): " + b);
    System.out.println("c (before): " + c);
    
    Measurement d = c.div(2);
    System.out.println("c (after): " + c);
    System.out.println("d: " + d);    
  }
  
  public void testImmutability2() {
    Length m3 = new ImmutableLength(new Meter(3));
    
    assertEquals(3, m3.getValue(Units.m), 0);
    
    Measurement mx6 = m3.mult(2);
    assertEquals(6, mx6.getValue(Units.m), 0);    
    
    mx6.mult(2);
    assertEquals(12, mx6.getValue(Units.m), 0);    
    
    assertEquals(3, m3.getValue(Units.m), 0);
  }
  
}
