/*
 * Copyright (C) 2002-2004 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE for more information.
 *
 * Created on April 26, 2004, 11:50 PM
 */

package org.xspace.mx;


import org.xspace.mx.physics.SI;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;
import org.xspace.mx.physics.mutable.Day;
import org.xspace.mx.physics.mutable.Degree;
import org.xspace.mx.physics.mutable.Foot;
import org.xspace.mx.physics.mutable.Hour;
import org.xspace.mx.physics.mutable.Kilogram;
import org.xspace.mx.physics.mutable.Meter;
import org.xspace.mx.physics.mutable.Minute;
import org.xspace.mx.physics.mutable.Radian;
import org.xspace.mx.physics.mutable.Second;
import org.xspace.mx.physics.mutable.Units;

/**
 *
 * @author Michel Santos
 */
public class SameMeasurementTester extends TestCase {
  
  public SameMeasurementTester(java.lang.String testName) {
    super(testName);
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(SameMeasurementTester.class);
    return suite;
  }
  
  public static void main(java.lang.String[] args) {
    TestRunner.run(suite());
  }
  
  
  public void testImmutable() {
    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Meter(5), new org.xspace.mx.physics.immutable.Meter(17)));
    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Meter(5), new org.xspace.mx.physics.immutable.Foot(17)));
    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Meter(5), org.xspace.mx.physics.immutable.Units.cm));
    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Meter(5), org.xspace.mx.physics.immutable.Units.cm.mult(94)));

    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Second(5), new org.xspace.mx.physics.immutable.Minute(17)));
    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Day(5), new org.xspace.mx.physics.immutable.Hour(17)));    

    assertTrue(SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Degree(5), new org.xspace.mx.physics.immutable.Radian(17)));
        
    assertTrue(!SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Meter(5), org.xspace.mx.physics.immutable.Units.N));
    assertTrue(!SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Kilogram(), org.xspace.mx.physics.immutable.Units.N));
    assertTrue(!SI.isSameMeasurementType(new org.xspace.mx.physics.immutable.Minute(), org.xspace.mx.physics.immutable.Units.N));
  }

  
  public void testMutable() {
    assertTrue(SI.isSameMeasurementType(new Meter(5), new Meter(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), new Foot(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), Units.cm));
    assertTrue(SI.isSameMeasurementType(new Meter(5), Units.cm.mult(94)));

    assertTrue(SI.isSameMeasurementType(new Second(5), new Minute(17)));
    assertTrue(SI.isSameMeasurementType(new Day(5), new Hour(17)));    

    assertTrue(SI.isSameMeasurementType(new Degree(5), new Radian(17)));
    
    assertTrue(!SI.isSameMeasurementType(new Meter(5), Units.N));
    assertTrue(!SI.isSameMeasurementType(new Kilogram(), Units.N));
    assertTrue(!SI.isSameMeasurementType(new Minute(), Units.N));
  }

  
  public void testCrossImplementationComparison() {
    assertTrue(SI.isSameMeasurementType(new Meter(5), new org.xspace.mx.physics.immutable.Meter(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), new org.xspace.mx.physics.immutable.Foot(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), org.xspace.mx.physics.immutable.Units.cm));
    assertTrue(SI.isSameMeasurementType(new Meter(5), org.xspace.mx.physics.immutable.Units.cm.mult(94)));

    assertTrue(SI.isSameMeasurementType(new Meter(5), new org.xspace.mx.physics.immutable.Meter(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), new org.xspace.mx.physics.immutable.Foot(17)));
    assertTrue(SI.isSameMeasurementType(new Meter(5), org.xspace.mx.physics.immutable.Units.cm));
    assertTrue(SI.isSameMeasurementType(new Meter(5), org.xspace.mx.physics.immutable.Units.cm.mult(94)));
    
    
    assertTrue(!SI.isSameMeasurementType(new Meter(5), org.xspace.mx.physics.immutable.Units.N));
    assertTrue(!SI.isSameMeasurementType(new Kilogram(), org.xspace.mx.physics.immutable.Units.N));
    assertTrue(!SI.isSameMeasurementType(new Minute(), org.xspace.mx.physics.immutable.Units.N));
  }
  
}
