/*
 * Copyright (C) 2002-2004 Michel Santos (michel@xspace.org)
 * Licensed under the Academic Free License version 3.0
 * Please see the LICENSE for more information.
 *
 * Created on January 16, 2004, 2:38 PM
 */

package org.xspace.mx;


import java.io.*;
import org.xspace.mx.physics.immutable.Units;
import org.xspace.mx.physics.mutable.Meter;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;


/**
 *
 * @author Michel Santos
 */
public class SerializationTester extends TestCase {
  
  public SerializationTester(java.lang.String testName) {
    super(testName);
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(SerializationTester.class);
    return suite;
  }

  
  public static void main(java.lang.String[] args) {
    TestRunner.run(suite());
  }
  
  public void testSerializingImmutableMeter() throws FileNotFoundException, IOException, ClassNotFoundException {
    System.out.println();
    System.out.println("Serializing Immutable Meter");
    System.out.println();
    
    org.xspace.mx.physics.immutable.Meter mxMeter = new org.xspace.mx.physics.immutable.Meter(5);
    System.out.println("mxMeter (Before): " + mxMeter);
    
    String strFile = System.getProperty("java.io.tmpdir") + System.getProperty("file.separator") + "Meter.dat";
    
    ObjectOutputStream out = new ObjectOutputStream(new FileOutputStream(strFile));    
    out.writeObject(mxMeter);
    out.close();
    
    mxMeter.mult(2);
    System.out.println("mxMeter (After): " + mxMeter);
    
    ObjectInputStream in = new ObjectInputStream(new FileInputStream(strFile));
    org.xspace.mx.physics.immutable.Meter mxMeterCopy = (org.xspace.mx.physics.immutable.Meter) in.readObject();
    System.out.println("mxMeterCopy: " + mxMeterCopy);
    
    assertEquals(5, mxMeterCopy.getValue(Units.m), 0);
  }

  
  public void testSerializingMeasurement() throws FileNotFoundException, IOException, ClassNotFoundException {
    System.out.println();
    System.out.println("Deserializing Measurement");
    System.out.println();
    
    Measurement mxMeter = new org.xspace.mx.physics.immutable.Meter(5);
    System.out.println("mxMeter (Before): " + mxMeter);
    
    String strFile = System.getProperty("java.io.tmpdir") + System.getProperty("file.separator") + "Measurement.dat";
    
    ObjectOutputStream out= new ObjectOutputStream(new FileOutputStream(strFile));    
    out.writeObject(mxMeter);
    out.close();
    
    mxMeter.mult(2);
    System.out.println("mxMeter (After): " + mxMeter);
    
    ObjectInputStream in = new ObjectInputStream(new FileInputStream(strFile));
    Measurement mxMeterCopy = (Measurement) in.readObject();
    System.out.println("mxMeterCopy: " + mxMeterCopy);
    
    assertEquals(5, mxMeterCopy.getValue(Units.m), 0);
  }

  
  public void testSerializingMutableMeter() throws FileNotFoundException, IOException, ClassNotFoundException {
    System.out.println();
    System.out.println("Serializing Mutable Meter");
    System.out.println();
    
    Measurement mxMeter = new Meter(5);
    System.out.println("mxMeter (Before): " + mxMeter);
    
    String strFile = System.getProperty("java.io.tmpdir") + System.getProperty("file.separator") + "MeterImmutable.dat";
    
    ObjectOutputStream out= new ObjectOutputStream(new FileOutputStream(strFile));    
    out.writeObject(mxMeter);
    out.close();
    
    mxMeter.mult(2);
    System.out.println("mxMeter (After): " + mxMeter);
    
    ObjectInputStream in = new ObjectInputStream(new FileInputStream(strFile));
    Meter mxMeterCopy = (Meter) in.readObject();
    System.out.println("mxMeterCopy: " + mxMeterCopy);
    
    assertEquals(5, mxMeterCopy.getValue(Units.m), 0);
  }
  
  
}